==> kubernetes-model-4.1.0-sources.jar: io/fabric8/kubernetes/api/model/PodFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import javax.validation.Valid;
import java.lang.Object;

public class PodFluentImpl<A extends PodFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PodFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private PodSpecBuilder spec;
    private PodStatusBuilder status;

    public PodFluentImpl(){
    }
    public PodFluentImpl(Pod instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public PodFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public PodFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public PodFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public PodFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public PodFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PodSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public PodSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(PodSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new PodSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public PodFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public PodFluent.SpecNested<A> withNewSpecLike(PodSpec item){
            return new SpecNestedImpl(item);
    }

    public PodFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public PodFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new PodSpecBuilder().build());
    }

    public PodFluent.SpecNested<A> editOrNewSpecLike(PodSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public PodStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public PodStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(PodStatus status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new PodStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public PodFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public PodFluent.StatusNested<A> withNewStatusLike(PodStatus item){
            return new StatusNestedImpl(item);
    }

    public PodFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public PodFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new PodStatusBuilder().build());
    }

    public PodFluent.StatusNested<A> editOrNewStatusLike(PodStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodFluentImpl that = (PodFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodFluent.MetadataNested<N>> implements PodFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) PodFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends PodSpecFluentImpl<PodFluent.SpecNested<N>> implements PodFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PodSpecBuilder builder;
    
            SpecNestedImpl(PodSpec item){
                    this.builder = new PodSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new PodSpecBuilder(this);
            }
    
    public N and(){
            return (N) PodFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends PodStatusFluentImpl<PodFluent.StatusNested<N>> implements PodFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PodStatusBuilder builder;
    
            StatusNestedImpl(PodStatus item){
                    this.builder = new PodStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new PodStatusBuilder(this);
            }
    
    public N and(){
            return (N) PodFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> kubernetes-model-4.9.0-sources.jar: io/fabric8/kubernetes/api/model/PodFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Object;

public class PodFluentImpl<A extends PodFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PodFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private PodSpecBuilder spec;
    private PodStatusBuilder status;

    public PodFluentImpl(){
    }
    public PodFluentImpl(Pod instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public PodFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public PodFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public PodFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public PodFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public PodFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PodSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public PodSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(PodSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new PodSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public PodFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public PodFluent.SpecNested<A> withNewSpecLike(PodSpec item){
            return new SpecNestedImpl(item);
    }

    public PodFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public PodFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new PodSpecBuilder().build());
    }

    public PodFluent.SpecNested<A> editOrNewSpecLike(PodSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public PodStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public PodStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(PodStatus status){
            _visitables.get("status").remove(this.status);
            if (status!=null){ this.status= new PodStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public PodFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public PodFluent.StatusNested<A> withNewStatusLike(PodStatus item){
            return new StatusNestedImpl(item);
    }

    public PodFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public PodFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new PodStatusBuilder().build());
    }

    public PodFluent.StatusNested<A> editOrNewStatusLike(PodStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            PodFluentImpl that = (PodFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodFluent.MetadataNested<N>> implements PodFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) PodFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends PodSpecFluentImpl<PodFluent.SpecNested<N>> implements PodFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PodSpecBuilder builder;
    
            SpecNestedImpl(PodSpec item){
                    this.builder = new PodSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new PodSpecBuilder(this);
            }
    
    public N and(){
            return (N) PodFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends PodStatusFluentImpl<PodFluent.StatusNested<N>> implements PodFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PodStatusBuilder builder;
    
            StatusNestedImpl(PodStatus item){
                    this.builder = new PodStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new PodStatusBuilder(this);
            }
    
    public N and(){
            return (N) PodFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
